pub struct LANDING_TARGET_DATA {}dialect-ardupilotmega only.Expand description
The location of a landing target. See: https://mavlink.io/en/services/landing_target.html.
ID: 149
Fields
time_usec: u64Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
angle_x: f32X-axis angular offset of the target from the center of the image
angle_y: f32Y-axis angular offset of the target from the center of the image
distance: f32Distance to the target from the vehicle
size_x: f32Size of target along x-axis
size_y: f32Size of target along y-axis
target_num: u8The ID of the target if multiple targets are present
frame: MavFrameCoordinate frame used for following fields.
x: f32X Position of the landing target in MAV_FRAME
y: f32Y Position of the landing target in MAV_FRAME
z: f32Z Position of the landing target in MAV_FRAME
q: [f32; 4]Quaternion of landing target orientation (w, x, y, z order, zero-rotation is 1, 0, 0, 0)
mavtype: LandingTargetTypeType of landing target
position_valid: MavBoolPosition fields (x, y, z, q, type) contain valid target position information (MAV_BOOL_FALSE: invalid values). Values not equal to 0 or 1 are invalid.
Implementations