pub struct LOWEHEISER_GOV_EFI_DATA {Show 23 fields
pub volt_batt: f32,
pub curr_batt: f32,
pub curr_gen: f32,
pub curr_rot: f32,
pub fuel_level: f32,
pub throttle: f32,
pub runtime: u32,
pub until_maintenance: i32,
pub rectifier_temp: f32,
pub generator_temp: f32,
pub efi_batt: f32,
pub efi_rpm: f32,
pub efi_pw: f32,
pub efi_fuel_flow: f32,
pub efi_fuel_consumed: f32,
pub efi_baro: f32,
pub efi_mat: f32,
pub efi_clt: f32,
pub efi_tps: f32,
pub efi_exhaust_gas_temperature: f32,
pub generator_status: u16,
pub efi_status: u16,
pub efi_index: u8,
}dialect-ardupilotmega only.Expand description
Composite EFI and Governor data from Loweheiser equipment. This message is created by the EFI unit based on its own data and data received from a governor attached to that EFI unit.
ID: 10151
Fields
volt_batt: f32Generator Battery voltage.
curr_batt: f32Generator Battery current.
curr_gen: f32Current being produced by generator.
curr_rot: f32Load current being consumed by the UAV (sum of curr_gen and curr_batt)
fuel_level: f32Generator fuel remaining in litres.
throttle: f32Throttle Output.
runtime: u32Seconds this generator has run since it was rebooted.
until_maintenance: i32Seconds until this generator requires maintenance. A negative value indicates maintenance is past due.
rectifier_temp: f32The Temperature of the rectifier.
generator_temp: f32The temperature of the mechanical motor, fuel cell core or generator.
efi_batt: f32EFI Supply Voltage.
efi_rpm: f32Motor RPM.
efi_pw: f32Injector pulse-width in milliseconds.
efi_fuel_flow: f32Fuel flow rate in litres/hour.
efi_fuel_consumed: f32Fuel consumed.
efi_baro: f32Atmospheric pressure.
efi_mat: f32Manifold Air Temperature.
efi_clt: f32Cylinder Head Temperature.
efi_tps: f32Throttle Position.
efi_exhaust_gas_temperature: f32Exhaust gas temperature.
generator_status: u16Generator status.
efi_status: u16EFI status.
efi_index: u8EFI index.
Implementations