OPEN_DRONE_ID_LOCATION_DATA

Struct OPEN_DRONE_ID_LOCATION_DATA 

pub struct OPEN_DRONE_ID_LOCATION_DATA {
Show 19 fields pub latitude: i32, pub longitude: i32, pub altitude_barometric: f32, pub altitude_geodetic: f32, pub height: f32, pub timestamp: f32, pub direction: u16, pub speed_horizontal: u16, pub speed_vertical: i16, pub target_system: u8, pub target_component: u8, pub id_or_mac: [u8; 20], pub status: MavOdidStatus, pub height_reference: MavOdidHeightRef, pub horizontal_accuracy: MavOdidHorAcc, pub vertical_accuracy: MavOdidVerAcc, pub barometer_accuracy: MavOdidVerAcc, pub speed_accuracy: MavOdidSpeedAcc, pub timestamp_accuracy: MavOdidTimeAcc,
}
Available on crate feature dialect-ardupilotmega only.
Data for filling the OpenDroneID Location message. The float data types are 32-bit IEEE 754. The Location message provides the location, altitude, direction and speed of the aircraft.

ID: 12901

Fields

latitude: i32

Current latitude of the unmanned aircraft. If unknown: 0 (both Lat/Lon).

longitude: i32

Current longitude of the unmanned aircraft. If unknown: 0 (both Lat/Lon).

altitude_barometric: f32

The altitude calculated from the barometric pressure. Reference is against 29.92inHg or 1013.2mb. If unknown: -1000 m.

altitude_geodetic: f32

The geodetic altitude as defined by WGS84. If unknown: -1000 m.

height: f32

The current height of the unmanned aircraft above the take-off location or the ground as indicated by height_reference. If unknown: -1000 m.

timestamp: f32

Seconds after the full hour with reference to UTC time. Typically the GPS outputs a time-of-week value in milliseconds. First convert that to UTC and then convert for this field using ((float) (time_week_ms % (60601000))) / 1000. If unknown: 0xFFFF.

direction: u16

Direction over ground (not heading, but direction of movement) measured clockwise from true North: 0 - 35999 centi-degrees. If unknown: 36100 centi-degrees.

speed_horizontal: u16

Ground speed. Positive only. If unknown: 25500 cm/s. If speed is larger than 25425 cm/s, use 25425 cm/s.

speed_vertical: i16

The vertical speed. Up is positive. If unknown: 6300 cm/s. If speed is larger than 6200 cm/s, use 6200 cm/s. If lower than -6200 cm/s, use -6200 cm/s.

target_system: u8

System ID (0 for broadcast).

target_component: u8

Component ID (0 for broadcast).

id_or_mac: [u8; 20]

Only used for drone ID data received from other UAs. See detailed description at https://mavlink.io/en/services/opendroneid.html.

status: MavOdidStatus

Indicates whether the unmanned aircraft is on the ground or in the air.

height_reference: MavOdidHeightRef

Indicates the reference point for the height field.

horizontal_accuracy: MavOdidHorAcc

The accuracy of the horizontal position.

vertical_accuracy: MavOdidVerAcc

The accuracy of the vertical position.

barometer_accuracy: MavOdidVerAcc

The accuracy of the barometric altitude.

speed_accuracy: MavOdidSpeedAcc

The accuracy of the horizontal and vertical speed.

timestamp_accuracy: MavOdidTimeAcc

The accuracy of the timestamps.

Implementations

Source

impl OPEN_DRONE_ID_LOCATION_DATA

pub const ENCODED_LEN: usize = 59usize

pub const DEFAULT: Self

pub fn random<R: RngCore>(rng: &mut R) -> Self

Available on crate feature arbitrary only.