pub struct OPEN_DRONE_ID_SELF_ID_DATA {
pub target_system: u8,
pub target_component: u8,
pub id_or_mac: [u8; 20],
pub description_type: MavOdidDescType,
pub description: CharArray<23>,
}dialect-ardupilotmega only.Expand description
Data for filling the OpenDroneID Self ID message. The Self ID Message is an opportunity for the operator to (optionally) declare their identity and purpose of the flight. This message can provide additional information that could reduce the threat profile of a UA (Unmanned Aircraft) flying in a particular area or manner. This message can also be used to provide optional additional clarification in an emergency/remote ID system failure situation.
ID: 12903
Fields
target_system: u8System ID (0 for broadcast).
target_component: u8Component ID (0 for broadcast).
id_or_mac: [u8; 20]Only used for drone ID data received from other UAs. See detailed description at https://mavlink.io/en/services/opendroneid.html.
description_type: MavOdidDescTypeIndicates the type of the description field.
description: CharArray<23>Text description or numeric value expressed as ASCII characters. Shall be filled with nulls in the unused portion of the field.
Implementations