pub struct OPEN_DRONE_ID_SYSTEM_UPDATE_DATA {
pub operator_latitude: i32,
pub operator_longitude: i32,
pub operator_altitude_geo: f32,
pub timestamp: u32,
pub target_system: u8,
pub target_component: u8,
}Available on crate feature
dialect-ardupilotmega only.Expand description
Update the data in the OPEN_DRONE_ID_SYSTEM message with new location information. This can be sent to update the location information for the operator when no other information in the SYSTEM message has changed. This message allows for efficient operation on radio links which have limited uplink bandwidth while meeting requirements for update frequency of the operator location.
ID: 12919
Fields
operator_latitude: i32Latitude of the operator. If unknown: 0 (both Lat/Lon).
operator_longitude: i32Longitude of the operator. If unknown: 0 (both Lat/Lon).
operator_altitude_geo: f32Geodetic altitude of the operator relative to WGS84. If unknown: -1000 m.
timestamp: u3232 bit Unix Timestamp in seconds since 00:00:00 01/01/2019.
target_system: u8System ID (0 for broadcast).
target_component: u8Component ID (0 for broadcast).
Implementations