pub struct PARAM_REQUEST_READ_DATA {
pub param_index: i16,
pub target_system: u8,
pub target_component: u8,
pub param_id: CharArray<16>,
}dialect-ardupilotmega only.Expand description
Request to read the onboard parameter with the param_id string id. Onboard parameters are stored as key[const char*] ->value[float]. This allows to send a parameter to any other component (such as the GCS) without the need of previous knowledge of possible parameter names. Thus the same GCS can store different parameters for different autopilots. See also https://mavlink.io/en/services/parameter.html for a full documentation of QGroundControl and IMU code.
ID: 20
Fields
param_index: i16Parameter index. Send -1 to use the param ID field as identifier (else the param id will be ignored)
target_system: u8System ID
target_component: u8Component ID
param_id: CharArray<16>Onboard parameter id, terminated by NULL if the length is less than 16 human-readable chars and WITHOUT null termination (NULL) byte if the length is exactly 16 chars - applications have to provide 16+1 bytes storage if the ID is stored as string
Implementations