pub struct POSITION_TARGET_GLOBAL_INT_DATA {}dialect-ardupilotmega only.Expand description
Reports the current commanded vehicle position, velocity, and acceleration as specified by the autopilot. This should match the commands sent in SET_POSITION_TARGET_GLOBAL_INT if the vehicle is being controlled this way.
ID: 87
Fields
time_boot_ms: u32Timestamp (time since system boot). The rationale for the timestamp in the setpoint is to allow the system to compensate for the transport delay of the setpoint. This allows the system to compensate processing latency.
lat_int: i32Latitude in WGS84 frame
lon_int: i32Longitude in WGS84 frame
alt: f32Altitude (MSL, AGL or relative to home altitude, depending on frame)
vx: f32X velocity in NED frame
vy: f32Y velocity in NED frame
vz: f32Z velocity in NED frame
afx: f32X acceleration or force (if bit 10 of type_mask is set) in NED frame in meter / s^2 or N
afy: f32Y acceleration or force (if bit 10 of type_mask is set) in NED frame in meter / s^2 or N
afz: f32Z acceleration or force (if bit 10 of type_mask is set) in NED frame in meter / s^2 or N
yaw: f32yaw setpoint
yaw_rate: f32yaw rate setpoint
type_mask: PositionTargetTypemaskBitmap to indicate which dimensions should be ignored by the vehicle.
coordinate_frame: MavFrameValid options are: MAV_FRAME_GLOBAL = 0, MAV_FRAME_GLOBAL_RELATIVE_ALT = 3, MAV_FRAME_GLOBAL_TERRAIN_ALT = 10 (MAV_FRAME_GLOBAL_INT, MAV_FRAME_GLOBAL_RELATIVE_ALT_INT, MAV_FRAME_GLOBAL_TERRAIN_ALT_INT are allowed synonyms, but have been deprecated)
Implementations