pub struct WIND_COV_DATA {
pub time_usec: u64,
pub wind_x: f32,
pub wind_y: f32,
pub wind_z: f32,
pub var_horiz: f32,
pub var_vert: f32,
pub wind_alt: f32,
pub horiz_accuracy: f32,
pub vert_accuracy: f32,
}dialect-ardupilotmega only.Expand description
Wind estimate from vehicle. Note that despite the name, this message does not actually contain any covariances but instead variability and accuracy fields in terms of standard deviation (1-STD).
ID: 231
Fields
time_usec: u64Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
wind_x: f32Wind in North (NED) direction (NAN if unknown)
wind_y: f32Wind in East (NED) direction (NAN if unknown)
wind_z: f32Wind in down (NED) direction (NAN if unknown)
var_horiz: f32Variability of wind in XY, 1-STD estimated from a 1 Hz lowpassed wind estimate (NAN if unknown)
var_vert: f32Variability of wind in Z, 1-STD estimated from a 1 Hz lowpassed wind estimate (NAN if unknown)
wind_alt: f32Altitude (MSL) that this measurement was taken at (NAN if unknown)
horiz_accuracy: f32Horizontal speed 1-STD accuracy (0 if unknown)
vert_accuracy: f32Vertical speed 1-STD accuracy (0 if unknown)
Implementations